import logging
import sys

from prometheus_client import Counter, push_to_gateway
from prometheus_client import CollectorRegistry

logging.basicConfig(stream=sys.stdout, level=logging.INFO)


class MetricsClient:
    """
    A streaming metric client that instantiates a Prometheus Collector and provides metrics like count, latency.
    """

    def __init__(self, metric_prefix, metrics_push_gateway, metrics_port):
        """
        Initializes the Metrics Client
        :param metric_prefix: Prefix of all metrics sent to Wavefront
        :param metrics_port: Port on which metrics are sent
        :param app: The flask app for which we want to return
        """

        self.metric_prefix = metric_prefix
        self.metrics_port = int(metrics_port)
        self.metrics_gateway = metrics_push_gateway
        self.content_type = str("text/plain; version=0.0.4; charset=utf-8")

        self.registry = CollectorRegistry()

        self.org_processed_row_count = Counter(
            f"{self.metric_prefix}_org_processed_row_count",
            "Org processed Row Count",
            ["env", "app_name", "job_type", "org_key"],
            registry=self.registry,
        )

        self.org_error_row_count = Counter(
            f"{self.metric_prefix}_org_error_row_count",
            "Org error Row Count",
            ["env", "app_name", "job_type", "org_key"],
            registry=self.registry,
        )

    def push_metrics_to_gateway(self):
        try:
            logging.info(f'Pushing metrics to {self.metrics_gateway}:{self.metrics_port}')
            push_to_gateway(f'{self.metrics_gateway}:{self.metrics_port}', job='mdr-reporting-job', registry=self.registry)
            logging.info(f'Pushed metrics to {self.metrics_gateway}:{self.metrics_port}')
        except Exception as ex:
            logging.exception(f'Failed to push metrics to prometheus {self.metrics_gateway}:{self.metrics_port} {ex}')
